@@ -589,6 +589,37 @@ class CoreDriver(BaseDriver):
         response = self.request('midas.item.searchbyname', parameters)
         return response['items']
 
+    def create_link(self, token, folder_id, url, **kwargs):
+        """Create a link bitstream.
+
+        :param token: A valid token for the user in question.
+        :param folder_id: The id of the folder in which to create a new item
+        that will contain the link. The new item will have the same name as the
+        URL unless an item name is supplied.
+        :param url: The URL of the link you will create, will be used as the
+        name of the bitstream and of the item unless an item name is supplied.
+        :param item_name: (optional)  The name of the newly created item, if
+        not supplied, the item will have the same name as the URL.
+        :param length: (optional) The length in bytes of the file to which the
+        link points.
+        :param checksum: (optional) The MD5 checksum of the file to which the
+        link points.
+        :returns: The item information of the item created.
+        """
+        parameters = dict()
+        parameters['token'] = token
+        parameters['folderid'] = folder_id
+        parameters['url'] = url
+        optional_keys = ['item_name', 'length', 'checksum']
+        for key in optional_keys:
+            if key in kwargs:
+                if key == 'item_name':
+                    parameters['itemname'] = kwargs[key]
+                    continue
+                parameters[key] = kwargs[key]
+        response = self.request('midas.link.create', parameters)
+        return response
+
     def generate_upload_token(self, token, item_id, filename, checksum=None):
         """Generate a token to use for upload.
 
@@ -847,6 +878,8 @@ class TrackerDriver(BaseDriver):
         visible only to the user performing the submission.
         :param build_results_url: (optional) A URL for linking to build results
         for this submission.
+        :param branch: (optional) The branch name in the source repository for
+        this submission.
         :returns: The scalar object that was created.
         """
         parameters = dict()
@@ -859,7 +892,7 @@ class TrackerDriver(BaseDriver):
         parameters['value'] = value
         optional_keys = [
             'config_item_id', 'test_dataset_id', 'truth_dataset_id', 'silent',
-            'unofficial', 'build_results_url']
+            'unofficial', 'build_results_url', 'branch']
         for key in optional_keys:
             if key in kwargs:
                 if key == 'config_item_id':
@@ -908,6 +941,10 @@ class TrackerDriver(BaseDriver):
         notifications for this scalar.
         :param unofficial: (optional) If true, creates an unofficial scalar
         visible only to the user performing the submission.
+        :param build_results_url: (optional) A URL for linking to build results
+        for this submission.
+        :param branch: (optional) The branch name in the source repository for
+        this submission.
         :returns: The list of scalars that were created.
         """
         parameters = dict()
@@ -919,7 +956,7 @@ class TrackerDriver(BaseDriver):
         parameters['submitTime'] = submit_time
         optional_keys = [
             'config_item_id', 'test_dataset_id', 'truth_dataset_id', 'silent',
-            'unofficial', 'build_results_url']
+            'unofficial', 'build_results_url', 'branch']
         for key in optional_keys:
             if key in kwargs:
                 if key == 'config_item_id':
